@@ -13,20 +13,22 @@ to download information from the main source: https://www.ospo.noaa.gov/Products
 
 '''
 class HMSFire:
-  def __init__(self, startDate:str, endDate:str, load_file:str=None, skipDays:int=0):
+  def __init__(self, startDate:str='', endDate:str='', load_file:str=None, skipDays:int=0):
     self.startDate = startDate
     self.endDate = endDate
     if load_file != None:
       self.data = pd.read_csv(load_file, skipinitialspace=True)
-      self.data = self.data[~data.duplicated()]
+      self.data = self.data[~self.data.duplicated()]
       self.data.columns = self.data.columns.str.replace(' ', '')
+      self.startDate = self.data.Time.min()
+      self.endDate = self.data.Time.max()
     else:
        self.data = self.adquire(startDate=startDate, endDate=endDate)
   def getDataFrame(self):
     return self.data
 
   def getXarray(self):
-    return data.set_index('Time').to_xarray()
+    return self.data.set_index('Time').to_xarray()
 
   def update(self, startDate:str, endDate:str):
     ##TODO: apply a smart update...
